@@ -9,16 +9,16 @@ sub base_url {  'http://www.yssm.org' }
 
 sub charset { 'utf8' }
 
-sub scrape_index { {
+sub scrape_novel { {
         writer => { regex => '<meta property="og:novel:author" content="(.+?)"/>', }, 
         book=>{ regex => '<meta property="og:novel:book_name" content="(.+?)"/>', }, 
     } }
 
-sub scrape_chapter_list {
+sub scrape_novel_list {
     { path => '//dl[@class="chapterlist"]//dd//a'}
 }
 
-sub scrape_chapter { {
+sub scrape_novel_item { {
         title => { path => '//h1' }, 
         content=>{ path => '//div[@id="content"]', extract => 'HTML' }, 
     } }
